==> photoupload.6.4.7.789.zip: photoupload.lrplugin/AlbumPhotos.lua <==
LuaQ     @AlbumPhotos.lua           6   
   E   @  \                $A     d          	      	A      	      	           	      	A       	    	    	        	    
      require 
   NPPLogger 
   NPPUtilities    addAlbumPhoto    albumPhotosFromPhoto    albumPhotoFromRemoteID    findAlbumPhoto    remoteIDFromAlbumPhoto    removeAlbumPhoto    saveAlbumPhotos    savePhotoHasBeenExported    savePhotoHasBeenPublished    updateAlbumPhotos 
       $   Q    K       @      Z   
A  A   F@ \   @A
A    A   ܁   @ @  D F \ CB@BB CB  C      @  @    C ƃ @Ca   @  @ 
      @A  A        
   logOutput    require    NPPJSON    jsonDecode    type    table    ServiceManager    serviceFile    sortedPairs    albumID     albumExistedOnService 
   albumType    albumIsRoot    insert    INFO    Album/Photos =      K   %   %   %   '   )   )   )   )   *   *   *   +   +   +   -   -   -   -   -   .   .   .   /   /   /   0   2   2   3   4   4   6   6   6   6   6   9   9   9   :   :   :   ;   ;   ;   <   <   <   <   <   =   =   >   >   ?   ?   A   A   A   A   A   6   C   J   J   K   K   N   N   N   N   N   N   P   Q         service     J      account     J      serialisedAlbumPhotos     J      albumPhotos    J      NPPJSON    ?      serviceAccountAlbumPhotos    ?      ServiceManager    ?      serviceFile    ?      accountAlbumPhotos    ?      (for generator) #   ?      (for state) #   ?      (for control) #   ?      key $   =      albumPhoto $   =   
   isAlbumPhoto 2   =      
   NPPLogger 
   NPPUtilities     U   w    
0     @A  EA    \        ܁    ܁ W@@   A  @      Z    A   ܁ @   FZB  @ J  AFI   ܁     	   
   logOutput    require    NPPJSON    jsonDecode    type    table    ServiceManager    serviceFile    jsonEncode     0   V   V   V   X   Z   Z   Z   [   \   \   ]   ]   ]   ]   b   b   b   b   b   c   c   e   e   f   f   j   j   j   j   k   k   k   l   l   l   m   m   m   n   n   p   p   t   t   t   t   v   w   	      service     /      account     /      existingSerialisedAlbumPhotos     /      albumPhotos     /      serialisedAlbumPhotos    /      NPPJSON    /      serviceAccountAlbumPhotos    /      ServiceManager     *      serviceFile #   *      
   NPPLogger     {       7     @A  D  FA      A  \A B       A     @ A@         B  B   B Z  @   AZA       @A   @ A       
   logOutput    INFO    Looking for album =     , extension =     require    ServiceManager       ?   albumIDsMatch    albumID    photoExtension    Album index =      7   |   |   |   ~                                                                                                                                                                  albumPhotos     6      service     6      albumID     6      photoExtension     6      index    6      found 
   6      ServiceManager    ,      albumPhoto    +      
   NPPLogger                   @@ @      Z   @ŀ     A  @     @ŀ  @   T @     A   @        
   logOutput       Y@   table    insert       ?   remove    INFO    Album/photo =                                                                                                            albumPhotos           albumPhoto           maxAlbumPhotos          
   NPPLogger            	       @  A@     D      \  D  F A  \A        
   logOutput    getPropertyForPlugin    _PLUGIN    AlbumPhotoPairs    INFO    All Albums/photos =                                                                                 service           account           photo           albumPhotos          value          
   NPPLogger    deserialiseAlbumPhotos            	       @    @AA     A  @     T @   AD  FA  A  \A        
   logOutput    INFO 
   Remote ID =                ?   Album/photo =                                                                                                service           account        	   remoteID           albumPhoto          albumPhotos          
   NPPLogger    deserialiseAlbumPhotos            
     @A  D      @\Z    A   @A    @ A       
   logOutput    INFO    Album/photo =                                                                              albumPhotos           service           albumID           photoExtension           albumPhoto          index 
         
   NPPLogger    indexInAlbumPhotos                  @  
  D FA   \AC    @          
   logOutput    addAlbumPhoto                                                                        albumPhoto           service           account        	   remoteID          albumPhotos          existingValue          
   NPPLogger    AlbumPhotos    serialiseAlbumPhotos          
     @A  @        EA  F   \AD      @\  D  F      \A      
   logOutput    table    remove    INFO 
   Album/Photo                               
  
  
  
  
                                      albumPhotos           service           albumID           photoExtension           index 	         
   NPPLogger    indexInAlbumPhotos       *   
     @A A@      D     @\ A    AB BBB $        B      
   logOutput    getPropertyForPlugin    _PLUGIN    AlbumPhotoPairs    require    NPPTaskManager    timeout       >@   catalog    withPrivateWriteAccessDo 
   functionCall    setPropertyForPlugin        #  &      D   K  @    D \@        setPropertyForPlugin    _PLUGIN    AlbumPhotoPairs        $  $  $  $  $  $  &        context              photo    valueAlbumPhotos                                              !  "  &  &  &  !  )     *        photo           service           account           albumPhotos        	   oldValue          valueAlbumPhotos 
         NPPTaskManager          timeoutParameters          
   NPPLogger    serialiseAlbumPhotos     .  D   
       @@   Z    @    ܀   @    ܀    A ܀ 
  	AFB KAƁ d         ܁  \A      
   logOutput    LOC -   $$$/NPPUpload/Metadata/ExportedPhoto/Yes=Yes )   $$$/NPPUpload/Metadata/ExportedPhoto/No=    require    NPPTaskManager    timeout       >@   catalog    withPrivateWriteAccessDo 
   functionCall    setPropertyForPlugin        >  @      D   K  @    D \@        setPropertyForPlugin    _PLUGIN 	   Exported        ?  ?  ?  ?  ?  ?  @        context              photo    valueExportedPhoto    /  /  /  1  2  2  3  3  3  3  3  5  5  5  5  8  8  8  9  :  ;  ;  <  =  @  @  @  <  C  ;  D        photo           photoHasBeenExported           valueExportedPhoto          NPPTaskManager          timeoutParameters          
   NPPLogger     H  ^   
       @@   Z    @    ܀   @    ܀    A ܀ 
  	AFB KAƁ d         ܁  \A      
   logOutput    LOC .   $$$/NPPUpload/Metadata/PublishedPhoto/Yes=Yes *   $$$/NPPUpload/Metadata/PublishedPhoto/No=    require    NPPTaskManager    timeout       >@   catalog    withPrivateWriteAccessDo 
   functionCall    setPropertyForPlugin        X  Z      D   K  @    D \@        setPropertyForPlugin    _PLUGIN 
   Published        Y  Y  Y  Y  Y  Y  Z        context              photo    valuePublishedPhoto    I  I  I  K  L  L  M  M  M  M  M  O  O  O  O  R  R  R  S  T  U  U  V  W  Z  Z  Z  V  ]  U  ^        photo           photoHasBeenPublished           valuePublishedPhoto          NPPTaskManager          timeoutParameters          
   NPPLogger     b  x   
3     @A   A  @   ܁  Ɓ  @ ܁   @@   B 
    A A@ BBB   B@      B      
   logOutput    albumPhotosFromPhoto    findAlbumPhoto    removeAlbumPhoto    albumID    photoExtension    addAlbumPhoto    photoID 
   photoUUID    getRawMetadata    uuid    saveAlbumPhotos     3   c  c  c  e  h  h  h  h  h  h  h  i  i  i  i  i  i  i  j  j  l  l  l  l  l  l  l  l  n  n  o  p  r  r  r  r  r  s  t  t  t  t  u  u  u  u  u  u  u  w  x        photo     2      service     2      account     2      albumID     2      photoID     2      photoExtension     2      albumPhotos    2      albumPhoto    2      
   NPPLogger    AlbumPhotos 6                           Q   Q   Q   w   w                                                                         *  *  *    D  D  .  ^  ^  H  x  x  x  b  |  |        AlbumPhotos    5   
   NPPLogger    5   
   NPPUtilities    5      deserialiseAlbumPhotos 
   5      serialiseAlbumPhotos    5      indexInAlbumPhotos    5       

==> photoupload.6.4.7.852.zip: photoupload.lrplugin/AlbumPhotos.lua <==
LuaQ     @AlbumPhotos.lua           6   
   E   @  \                $A     d          	      	A      	      	           	      	A       	    	    	        	    
      require 
   NPPLogger 
   NPPUtilities    addAlbumPhoto    albumPhotosFromPhoto    albumPhotoFromRemoteID    findAlbumPhoto    remoteIDFromAlbumPhoto    removeAlbumPhoto    saveAlbumPhotos    savePhotoHasBeenExported    savePhotoHasBeenPublished    updateAlbumPhotos 
       $   Q    K       @      Z   
A  A   F@ \   @A
A    A   ܁   @ @  D F \ CB@BB CB  C      @  @    C ƃ @Ca   @  @ 
      @A  A        
   logOutput    require    NPPJSON    jsonDecode    type    table    ServiceManager    serviceFile    sortedPairs    albumID     albumExistedOnService 
   albumType    albumIsRoot    insert    INFO    Album/Photos =      K   %   %   %   '   )   )   )   )   *   *   *   +   +   +   -   -   -   -   -   .   .   .   /   /   /   0   2   2   3   4   4   6   6   6   6   6   9   9   9   :   :   :   ;   ;   ;   <   <   <   <   <   =   =   >   >   ?   ?   A   A   A   A   A   6   C   J   J   K   K   N   N   N   N   N   N   P   Q         service     J      account     J      serialisedAlbumPhotos     J      albumPhotos    J      NPPJSON    ?      serviceAccountAlbumPhotos    ?      ServiceManager    ?      serviceFile    ?      accountAlbumPhotos    ?      (for generator) #   ?      (for state) #   ?      (for control) #   ?      key $   =      albumPhoto $   =   
   isAlbumPhoto 2   =      
   NPPLogger 
   NPPUtilities     U   w    
0     @A  EA    \        ܁    ܁ W@@   A  @      Z    A   ܁ @   FZB  @ J  AFI   ܁     	   
   logOutput    require    NPPJSON    jsonDecode    type    table    ServiceManager    serviceFile    jsonEncode     0   V   V   V   X   Z   Z   Z   [   \   \   ]   ]   ]   ]   b   b   b   b   b   c   c   e   e   f   f   j   j   j   j   k   k   k   l   l   l   m   m   m   n   n   p   p   t   t   t   t   v   w   	      service     /      account     /      existingSerialisedAlbumPhotos     /      albumPhotos     /      serialisedAlbumPhotos    /      NPPJSON    /      serviceAccountAlbumPhotos    /      ServiceManager     *      serviceFile #   *      
   NPPLogger     {       7     @A  D  FA      A  \A B       A     @ A@         B  B   B Z  @   AZA       @A   @ A       
   logOutput    INFO    Looking for album =     , extension =     require    ServiceManager       ?   albumIDsMatch    albumID    photoExtension    Album index =      7   |   |   |   ~                                                                                                                                                                  albumPhotos     6      service     6      albumID     6      photoExtension     6      index    6      found 
   6      ServiceManager    ,      albumPhoto    +      
   NPPLogger                   @@ @      Z   @ŀ     A  @     @ŀ  @   T @     A   @        
   logOutput       Y@   table    insert       ?   remove    INFO    Album/photo =                                                                                                            albumPhotos           albumPhoto           maxAlbumPhotos          
   NPPLogger            	       @  A@     D      \  D  F A  \A        
   logOutput    getPropertyForPlugin    _PLUGIN    AlbumPhotoPairs    INFO    All Albums/photos =                                                                                 service           account           photo           albumPhotos          value          
   NPPLogger    deserialiseAlbumPhotos            	       @    @AA     A  @     T @   AD  FA  A  \A        
   logOutput    INFO 
   Remote ID =                ?   Album/photo =                                                                                                service           account        	   remoteID           albumPhoto          albumPhotos          
   NPPLogger    deserialiseAlbumPhotos            
     @A  D      @\Z    A   @A    @ A       
   logOutput    INFO    Album/photo =                                                                              albumPhotos           service           albumID           photoExtension           albumPhoto          index 
         
   NPPLogger    indexInAlbumPhotos                  @  
  D FA   \AC    @          
   logOutput    addAlbumPhoto                                                                        albumPhoto           service           account        	   remoteID          albumPhotos          existingValue          
   NPPLogger    AlbumPhotos    serialiseAlbumPhotos          
     @A  @        EA  F   \AD      @\  D  F      \A      
   logOutput    table    remove    INFO 
   Album/Photo                               
  
  
  
  
                                      albumPhotos           service           albumID           photoExtension           index 	         
   NPPLogger    indexInAlbumPhotos       *   
     @A A@      D     @\ A    AB BBB $        B      
   logOutput    getPropertyForPlugin    _PLUGIN    AlbumPhotoPairs    require    NPPTaskManager    timeout       >@   catalog    withPrivateWriteAccessDo 
   functionCall    setPropertyForPlugin        #  &      D   K  @    D \@        setPropertyForPlugin    _PLUGIN    AlbumPhotoPairs        $  $  $  $  $  $  &        context              photo    valueAlbumPhotos                                              !  "  &  &  &  !  )     *        photo           service           account           albumPhotos        	   oldValue          valueAlbumPhotos 
         NPPTaskManager          timeoutParameters          
   NPPLogger    serialiseAlbumPhotos     .  D   
       @@   Z    @    ܀   @    ܀    A ܀ 
  	AFB KAƁ d         ܁  \A      
   logOutput    LOC ?   $$$/NPP/PhotoUpload/AlbumPhotos/Metadata/ExportedPhoto/Yes=Yes ;   $$$/NPP/PhotoUpload/AlbumPhotos/Metadata/ExportedPhoto/No=    require    NPPTaskManager    timeout       >@   catalog    withPrivateWriteAccessDo 
   functionCall    setPropertyForPlugin        >  @      D   K  @    D \@        setPropertyForPlugin    _PLUGIN 	   Exported        ?  ?  ?  ?  ?  ?  @        context              photo    valueExportedPhoto    /  /  /  1  2  2  3  3  3  3  3  5  5  5  5  8  8  8  9  :  ;  ;  <  =  @  @  @  <  C  ;  D        photo           photoHasBeenExported           valueExportedPhoto          NPPTaskManager          timeoutParameters          
   NPPLogger     H  ^   
       @@   Z    @    ܀   @    ܀    A ܀ 
  	AFB KAƁ d         ܁  \A      
   logOutput    LOC @   $$$/NPP/PhotoUpload/AlbumPhotos/Metadata/PublishedPhoto/Yes=Yes <   $$$/NPP/PhotoUpload/AlbumPhotos/Metadata/PublishedPhoto/No=    require    NPPTaskManager    timeout       >@   catalog    withPrivateWriteAccessDo 
   functionCall    setPropertyForPlugin        X  Z      D   K  @    D \@        setPropertyForPlugin    _PLUGIN 
   Published        Y  Y  Y  Y  Y  Y  Z        context              photo    valuePublishedPhoto    I  I  I  K  L  L  M  M  M  M  M  O  O  O  O  R  R  R  S  T  U  U  V  W  Z  Z  Z  V  ]  U  ^        photo           photoHasBeenPublished           valuePublishedPhoto          NPPTaskManager          timeoutParameters          
   NPPLogger     b  x   
3     @A   A  @   ܁  Ɓ  @ ܁   @@   B 
    A A@ BBB   B@      B      
   logOutput    albumPhotosFromPhoto    findAlbumPhoto    removeAlbumPhoto    albumID    photoExtension    addAlbumPhoto    photoID 
   photoUUID    getRawMetadata    uuid    saveAlbumPhotos     3   c  c  c  e  h  h  h  h  h  h  h  i  i  i  i  i  i  i  j  j  l  l  l  l  l  l  l  l  n  n  o  p  r  r  r  r  r  s  t  t  t  t  u  u  u  u  u  u  u  w  x        photo     2      service     2      account     2      albumID     2      photoID     2      photoExtension     2      albumPhotos    2      albumPhoto    2      
   NPPLogger    AlbumPhotos 6                           Q   Q   Q   w   w                                                                         *  *  *    D  D  .  ^  ^  H  x  x  x  b  |  |        AlbumPhotos    5   
   NPPLogger    5   
   NPPUtilities    5      deserialiseAlbumPhotos 
   5      serialiseAlbumPhotos    5      indexInAlbumPhotos    5       
